pub struct WpSecurityContextV1 { /* private fields */ }Expand description
client security context
The security context allows a client to register a new client and attach security context metadata to the connections.
When both are set, the combination of the application ID and the sandbox engine must uniquely identify an application. The same application ID will be used across instances (e.g. if the application is restarted, or if the application is started multiple times).
When both are set, the combination of the instance ID and the sandbox engine must uniquely identify a running instance of an application.
See also the Request enum for this interface.